==> js-2.0.tar.gz: js-2.0/_sym2str.h <==
/*
 * Copyright (c) 2007, to-do. All rights reserved.
 */
case K_var: *s = "var"; return (*n = 3);
case K_M_1_PI: *s = "M_1_PI"; return (*n = 6);
case K_unquote: *s = "unquote"; return (*n = 7);
case K_abs: *s = "abs"; return (*n = 3);
case K_round: *s = "round"; return (*n = 5);
case K_isinf: *s = "isinf"; return (*n = 5);
case K_case: *s = "case"; return (*n = 4);
case K_isBool: *s = "isBool"; return (*n = 6);
case K_close: *s = "close"; return (*n = 5);
case K_values: *s = "values"; return (*n = 6);
case K_toChar: *s = "toChar"; return (*n = 6);
case K_continue: *s = "continue"; return (*n = 8);
case K_reverse: *s = "reverse"; return (*n = 7);
case K_readfile: *s = "readfile"; return (*n = 8);
case K_M_SQRT2: *s = "M_SQRT2"; return (*n = 7);
case K_isObject: *s = "isObject"; return (*n = 8);
case K_while: *s = "while"; return (*n = 5);
case K_touch: *s = "touch"; return (*n = 5);
case K_break: *s = "break"; return (*n = 5);
case K_match: *s = "match"; return (*n = 5);
case K_replace: *s = "replace"; return (*n = 7);
case K_NAN: *s = "NAN"; return (*n = 3);
case K_getcwd: *s = "getcwd"; return (*n = 6);
case K_M_PI_2: *s = "M_PI_2"; return (*n = 6);
case K_index: *s = "index"; return (*n = 5);
case K_isNull: *s = "isNull"; return (*n = 6);
case K_M_PI_4: *s = "M_PI_4"; return (*n = 6);
case K_isArray: *s = "isArray"; return (*n = 7);
case K_fatime: *s = "fatime"; return (*n = 6);
case K_crypt: *s = "crypt"; return (*n = 5);
case K_unlink: *s = "unlink"; return (*n = 6);
case K_asin: *s = "asin"; return (*n = 4);
case K_printf: *s = "printf"; return (*n = 6);
case K_remove: *s = "remove"; return (*n = 6);
case K_label: *s = "label"; return (*n = 5);
case K_M_2_SQRTPI: *s = "M_2_SQRTPI"; return (*n = 10);
case K_exit: *s = "exit"; return (*n = 4);
case K_length: *s = "length"; return (*n = 6);
case K_sprintf: *s = "sprintf"; return (*n = 7);
case K_print: *s = "print"; return (*n = 5);
case K_tan: *s = "tan"; return (*n = 3);
case K_isChar: *s = "isChar"; return (*n = 6);
case K_throw: *s = "throw"; return (*n = 5);
case K_false: *s = "false"; return (*n = 5);
case K_isnan: *s = "isnan"; return (*n = 5);
case K_ceil: *s = "ceil"; return (*n = 4);
case K_switch: *s = "switch"; return (*n = 6);
case K_null: *s = "null"; return (*n = 4);
case K_gmtime: *s = "gmtime"; return (*n = 6);
case K_shift: *s = "shift"; return (*n = 5);
case K_substr: *s = "substr"; return (*n = 6);
case K_toFloat: *s = "toFloat"; return (*n = 7);
case K_fgid: *s = "fgid"; return (*n = 4);
case K_tmpfile: *s = "tmpfile"; return (*n = 7);
case K_eval: *s = "eval"; return (*n = 4);
case K_trim: *s = "trim"; return (*n = 4);
case K_rename: *s = "rename"; return (*n = 6);
case K_atan2: *s = "atan2"; return (*n = 5);
case K_time: *s = "time"; return (*n = 4);
case K_return: *s = "return"; return (*n = 6);
case K_floor: *s = "floor"; return (*n = 5);
case K_if: *s = "if"; return (*n = 2);
case K_fmtime: *s = "fmtime"; return (*n = 6);
case K_popen: *s = "popen"; return (*n = 5);
case K_sqrt: *s = "sqrt"; return (*n = 4);
case K_in: *s = "in"; return (*n = 2);
case K_splice: *s = "splice"; return (*n = 6);
case K_mkdir: *s = "mkdir"; return (*n = 5);
case K_catch: *s = "catch"; return (*n = 5);
case K_jconv: *s = "jconv"; return (*n = 5);
case K_chdir: *s = "chdir"; return (*n = 5);
case K_rewind: *s = "rewind"; return (*n = 6);
case K_new: *s = "new"; return (*n = 3);
case K_isfinite: *s = "isfinite"; return (*n = 8);
case K_exp: *s = "exp"; return (*n = 3);
case K_M_LOG10E: *s = "M_LOG10E"; return (*n = 8);
case K_dbopen: *s = "dbopen"; return (*n = 6);
case K_unshift: *s = "unshift"; return (*n = 7);
case K_foreach: *s = "foreach"; return (*n = 7);
case K_M_LN2: *s = "M_LN2"; return (*n = 5);
case K_this: *s = "this"; return (*n = 4);
case K_tempnam: *s = "tempnam"; return (*n = 7);
case K_atan: *s = "atan"; return (*n = 4);
case K_join: *s = "join"; return (*n = 4);
case K_try: *s = "try"; return (*n = 3);
case K_cos: *s = "cos"; return (*n = 3);
case K_symlink: *s = "symlink"; return (*n = 7);
case K_chown: *s = "chown"; return (*n = 5);
case K_pop: *s = "pop"; return (*n = 3);
case K_decode: *s = "decode"; return (*n = 6);
case K_max: *s = "max"; return (*n = 3);
case K_keys: *s = "keys"; return (*n = 4);
case K_pow: *s = "pow"; return (*n = 3);
case K_setenv: *s = "setenv"; return (*n = 6);
case K_min: *s = "min"; return (*n = 3);
case K_rindex: *s = "rindex"; return (*n = 6);
case K_toInt: *s = "toInt"; return (*n = 5);
case K_fmode: *s = "fmode"; return (*n = 5);
case K_sort: *s = "sort"; return (*n = 4);
case K_fcopy: *s = "fcopy"; return (*n = 5);
case K_isString: *s = "isString"; return (*n = 8);
case K_M_PI: *s = "M_PI"; return (*n = 4);
case K_printfile: *s = "printfile"; return (*n = 9);
case K_void: *s = "void"; return (*n = 4);
case K_chmod: *s = "chmod"; return (*n = 5);
case K_read: *s = "read"; return (*n = 4);
case K_trace: *s = "trace"; return (*n = 5);
case K_class: *s = "class"; return (*n = 5);
case K_pclose: *s = "pclose"; return (*n = 6);
case K_for: *s = "for"; return (*n = 3);
case K_unpack: *s = "unpack"; return (*n = 6);
case K_md5: *s = "md5"; return (*n = 3);
case K_log10: *s = "log10"; return (*n = 5);
case K_goto: *s = "goto"; return (*n = 4);
case K_delete: *s = "delete"; return (*n = 6);
case K_tell: *s = "tell"; return (*n = 4);
case K_fctime: *s = "fctime"; return (*n = 6);
case K_M_E: *s = "M_E"; return (*n = 3);
case K_fopen: *s = "fopen"; return (*n = 5);
case K_isInt: *s = "isInt"; return (*n = 5);
case K_function: *s = "function"; return (*n = 8);
case K_isFloat: *s = "isFloat"; return (*n = 7);
case K_fuid: *s = "fuid"; return (*n = 4);
case K_isNumber: *s = "isNumber"; return (*n = 8);
case K_println: *s = "println"; return (*n = 7);
case K_push: *s = "push"; return (*n = 4);
case K_do: *s = "do"; return (*n = 2);
case K_writefile: *s = "writefile"; return (*n = 9);
case K_unserial: *s = "unserial"; return (*n = 8);
case K_INFINITY: *s = "INFINITY"; return (*n = 8);
case K_system: *s = "system"; return (*n = 6);
case K_getc: *s = "getc"; return (*n = 4);
case K_M_2_PI: *s = "M_2_PI"; return (*n = 6);
case K_getenv: *s = "getenv"; return (*n = 6);
case K_acos: *s = "acos"; return (*n = 4);
case K_glob: *s = "glob"; return (*n = 4);
case K_fsize: *s = "fsize"; return (*n = 5);
case K_serial: *s = "serial"; return (*n = 6);
case K_else: *s = "else"; return (*n = 4);
case K_gets: *s = "gets"; return (*n = 4);
case K_quote: *s = "quote"; return (*n = 5);
case K_write: *s = "write"; return (*n = 5);
case K_toBool: *s = "toBool"; return (*n = 6);
case K_putc: *s = "putc"; return (*n = 4);
case K_untrace: *s = "untrace"; return (*n = 7);
case K_rand: *s = "rand"; return (*n = 4);
case K_M_SQRT1_2: *s = "M_SQRT1_2"; return (*n = 9);
case K_typeof: *s = "typeof"; return (*n = 6);
case K_encode: *s = "encode"; return (*n = 6);
case K_gmdate: *s = "gmdate"; return (*n = 6);
case K_default: *s = "default"; return (*n = 7);
case K_toString: *s = "toString"; return (*n = 8);
case K___LINE__: *s = "__LINE__"; return (*n = 8);
case K_flink: *s = "flink"; return (*n = 5);
case K_pack: *s = "pack"; return (*n = 4);
case K_M_LN10: *s = "M_LN10"; return (*n = 6);
case K_sin: *s = "sin"; return (*n = 3);
case K_true: *s = "true"; return (*n = 4);
case K_echo: *s = "echo"; return (*n = 4);
case K_puts: *s = "puts"; return (*n = 4);
case K_date: *s = "date"; return (*n = 4);
case K_load: *s = "load"; return (*n = 4);
case K___FILE__: *s = "__FILE__"; return (*n = 8);
case K_log: *s = "log"; return (*n = 3);
case K_toNumber: *s = "toNumber"; return (*n = 8);
case K_truncate: *s = "truncate"; return (*n = 8);
case K_split: *s = "split"; return (*n = 5);
case K_M_LOG2E: *s = "M_LOG2E"; return (*n = 7);
case K_seek: *s = "seek"; return (*n = 4);

==> js3.0.1.tar.gz: js3.0.1/_sym2str.h <==
/*
 * Copyright (c) 2007, to-do. All rights reserved.
 */
case K_var: *s = "var"; return (*n = 3);
case K_M_1_PI: *s = "M_1_PI"; return (*n = 6);
case K_unquote: *s = "unquote"; return (*n = 7);
case K_abs: *s = "abs"; return (*n = 3);
case K_round: *s = "round"; return (*n = 5);
case K_isinf: *s = "isinf"; return (*n = 5);
case K_case: *s = "case"; return (*n = 4);
case K_isBool: *s = "isBool"; return (*n = 6);
case K_close: *s = "close"; return (*n = 5);
case K_values: *s = "values"; return (*n = 6);
case K_count: *s = "count"; return (*n = 5);
case K_toChar: *s = "toChar"; return (*n = 6);
case K_continue: *s = "continue"; return (*n = 8);
case K_reverse: *s = "reverse"; return (*n = 7);
case K_readfile: *s = "readfile"; return (*n = 8);
case K_M_SQRT2: *s = "M_SQRT2"; return (*n = 7);
case K_while: *s = "while"; return (*n = 5);
case K_isObject: *s = "isObject"; return (*n = 8);
case K_modify: *s = "modify"; return (*n = 6);
case K_touch: *s = "touch"; return (*n = 5);
case K_break: *s = "break"; return (*n = 5);
case K_match: *s = "match"; return (*n = 5);
case K_replace: *s = "replace"; return (*n = 7);
case K_NAN: *s = "NAN"; return (*n = 3);
case K_getcwd: *s = "getcwd"; return (*n = 6);
case K_M_PI_2: *s = "M_PI_2"; return (*n = 6);
case K_index: *s = "index"; return (*n = 5);
case K_isNull: *s = "isNull"; return (*n = 6);
case K_mktime: *s = "mktime"; return (*n = 6);
case K_M_PI_4: *s = "M_PI_4"; return (*n = 6);
case K_isArray: *s = "isArray"; return (*n = 7);
case K_fatime: *s = "fatime"; return (*n = 6);
case K_stdout: *s = "stdout"; return (*n = 6);
case K_crypt: *s = "crypt"; return (*n = 5);
case K_printf: *s = "printf"; return (*n = 6);
case K_asin: *s = "asin"; return (*n = 4);
case K_unlink: *s = "unlink"; return (*n = 6);
case K_remove: *s = "remove"; return (*n = 6);
case K_label: *s = "label"; return (*n = 5);
case K_M_2_SQRTPI: *s = "M_2_SQRTPI"; return (*n = 10);
case K_exit: *s = "exit"; return (*n = 4);
case K_length: *s = "length"; return (*n = 6);
case K_sprintf: *s = "sprintf"; return (*n = 7);
case K_print: *s = "print"; return (*n = 5);
case K_tan: *s = "tan"; return (*n = 3);
case K_timegm: *s = "timegm"; return (*n = 6);
case K_repmatch: *s = "repmatch"; return (*n = 8);
case K_isChar: *s = "isChar"; return (*n = 6);
case K_throw: *s = "throw"; return (*n = 5);
case K_false: *s = "false"; return (*n = 5);
case K_isnan: *s = "isnan"; return (*n = 5);
case K_ceil: *s = "ceil"; return (*n = 4);
case K_switch: *s = "switch"; return (*n = 6);
case K_null: *s = "null"; return (*n = 4);
case K_shift: *s = "shift"; return (*n = 5);
case K_substr: *s = "substr"; return (*n = 6);
case K_fetch: *s = "fetch"; return (*n = 5);
case K_toFloat: *s = "toFloat"; return (*n = 7);
case K_fgid: *s = "fgid"; return (*n = 4);
case K_tmpfile: *s = "tmpfile"; return (*n = 7);
case K_eval: *s = "eval"; return (*n = 4);
case K_trim: *s = "trim"; return (*n = 4);
case K_rename: *s = "rename"; return (*n = 6);
case K_atan2: *s = "atan2"; return (*n = 5);
case K_time: *s = "time"; return (*n = 4);
case K_return: *s = "return"; return (*n = 6);
case K_floor: *s = "floor"; return (*n = 5);
case K_if: *s = "if"; return (*n = 2);
case K_tracef: *s = "tracef"; return (*n = 6);
case K_fmtime: *s = "fmtime"; return (*n = 6);
case K_sqrt: *s = "sqrt"; return (*n = 4);
case K_popen: *s = "popen"; return (*n = 5);
case K_in: *s = "in"; return (*n = 2);
case K_splice: *s = "splice"; return (*n = 6);
case K_mkdir: *s = "mkdir"; return (*n = 5);
case K_catch: *s = "catch"; return (*n = 5);
case K_jconv: *s = "jconv"; return (*n = 5);
case K_chdir: *s = "chdir"; return (*n = 5);
case K_traces: *s = "traces"; return (*n = 6);
case K_rewind: *s = "rewind"; return (*n = 6);
case K_new: *s = "new"; return (*n = 3);
case K_isfinite: *s = "isfinite"; return (*n = 8);
case K_exp: *s = "exp"; return (*n = 3);
case K_M_LOG10E: *s = "M_LOG10E"; return (*n = 8);
case K_dbopen: *s = "dbopen"; return (*n = 6);
case K_unshift: *s = "unshift"; return (*n = 7);
case K_foreach: *s = "foreach"; return (*n = 7);
case K_M_LN2: *s = "M_LN2"; return (*n = 5);
case K_sum: *s = "sum"; return (*n = 3);
case K_this: *s = "this"; return (*n = 4);
case K_tempnam: *s = "tempnam"; return (*n = 7);
case K_atan: *s = "atan"; return (*n = 4);
case K_join: *s = "join"; return (*n = 4);
case K_try: *s = "try"; return (*n = 3);
case K_cos: *s = "cos"; return (*n = 3);
case K_symlink: *s = "symlink"; return (*n = 7);
case K_chown: *s = "chown"; return (*n = 5);
case K_pop: *s = "pop"; return (*n = 3);
case K_decode: *s = "decode"; return (*n = 6);
case K_max: *s = "max"; return (*n = 3);
case K_keys: *s = "keys"; return (*n = 4);
case K_xmlopen: *s = "xmlopen"; return (*n = 7);
case K_pow: *s = "pow"; return (*n = 3);
case K_setenv: *s = "setenv"; return (*n = 6);
case K_min: *s = "min"; return (*n = 3);
case K_rindex: *s = "rindex"; return (*n = 6);
case K_toInt: *s = "toInt"; return (*n = 5);
case K_fmode: *s = "fmode"; return (*n = 5);
case K_sort: *s = "sort"; return (*n = 4);
case K_fcopy: *s = "fcopy"; return (*n = 5);
case K_isString: *s = "isString"; return (*n = 8);
case K_M_PI: *s = "M_PI"; return (*n = 4);
case K_printfile: *s = "printfile"; return (*n = 9);
case K_void: *s = "void"; return (*n = 4);
case K_chmod: *s = "chmod"; return (*n = 5);
case K_read: *s = "read"; return (*n = 4);
case K_trace: *s = "trace"; return (*n = 5);
case K_class: *s = "class"; return (*n = 5);
case K_pclose: *s = "pclose"; return (*n = 6);
case K_for: *s = "for"; return (*n = 3);
case K_unpack: *s = "unpack"; return (*n = 6);
case K_md5: *s = "md5"; return (*n = 3);
case K_log10: *s = "log10"; return (*n = 5);
case K_goto: *s = "goto"; return (*n = 4);
case K_delete: *s = "delete"; return (*n = 6);
case K_tell: *s = "tell"; return (*n = 4);
case K_fctime: *s = "fctime"; return (*n = 6);
case K_M_E: *s = "M_E"; return (*n = 3);
case K_fopen: *s = "fopen"; return (*n = 5);
case K_isInt: *s = "isInt"; return (*n = 5);
case K_unentity: *s = "unentity"; return (*n = 8);
case K_isFloat: *s = "isFloat"; return (*n = 7);
case K_function: *s = "function"; return (*n = 8);
case K_isNumber: *s = "isNumber"; return (*n = 8);
case K_fuid: *s = "fuid"; return (*n = 4);
case K_push: *s = "push"; return (*n = 4);
case K_println: *s = "println"; return (*n = 7);
case K_writefile: *s = "writefile"; return (*n = 9);
case K_do: *s = "do"; return (*n = 2);
case K_unserial: *s = "unserial"; return (*n = 8);
case K_INFINITY: *s = "INFINITY"; return (*n = 8);
case K_system: *s = "system"; return (*n = 6);
case K_getc: *s = "getc"; return (*n = 4);
case K_entity: *s = "entity"; return (*n = 6);
case K_M_2_PI: *s = "M_2_PI"; return (*n = 6);
case K_getenv: *s = "getenv"; return (*n = 6);
case K_acos: *s = "acos"; return (*n = 4);
case K_glob: *s = "glob"; return (*n = 4);
case K_fsize: *s = "fsize"; return (*n = 5);
case K_serial: *s = "serial"; return (*n = 6);
case K_else: *s = "else"; return (*n = 4);
case K_gets: *s = "gets"; return (*n = 4);
case K_quote: *s = "quote"; return (*n = 5);
case K_write: *s = "write"; return (*n = 5);
case K_toBool: *s = "toBool"; return (*n = 6);
case K_putc: *s = "putc"; return (*n = 4);
case K_rand: *s = "rand"; return (*n = 4);
case K_untrace: *s = "untrace"; return (*n = 7);
case K_M_SQRT1_2: *s = "M_SQRT1_2"; return (*n = 9);
case K_formatf: *s = "formatf"; return (*n = 7);
case K_typeof: *s = "typeof"; return (*n = 6);
case K_encode: *s = "encode"; return (*n = 6);
case K_gmdate: *s = "gmdate"; return (*n = 6);
case K_default: *s = "default"; return (*n = 7);
case K_toString: *s = "toString"; return (*n = 8);
case K_stderr: *s = "stderr"; return (*n = 6);
case K___LINE__: *s = "__LINE__"; return (*n = 8);
case K_flink: *s = "flink"; return (*n = 5);
case K_pack: *s = "pack"; return (*n = 4);
case K_M_LN10: *s = "M_LN10"; return (*n = 6);
case K_sin: *s = "sin"; return (*n = 3);
case K_true: *s = "true"; return (*n = 4);
case K_formats: *s = "formats"; return (*n = 7);
case K_echo: *s = "echo"; return (*n = 4);
case K_puts: *s = "puts"; return (*n = 4);
case K_date: *s = "date"; return (*n = 4);
case K_stdin: *s = "stdin"; return (*n = 5);
case K_load: *s = "load"; return (*n = 4);
case K___FILE__: *s = "__FILE__"; return (*n = 8);
case K_log: *s = "log"; return (*n = 3);
case K_toNumber: *s = "toNumber"; return (*n = 8);
case K_select: *s = "select"; return (*n = 6);
case K_truncate: *s = "truncate"; return (*n = 8);
case K_split: *s = "split"; return (*n = 5);
case K_M_LOG2E: *s = "M_LOG2E"; return (*n = 7);
case K_seek: *s = "seek"; return (*n = 4);
